@@ -33,7 +33,7 @@ class KMFIPTDoc;
 
 
 
-class KDE_EXPORT KMFCompilerInterface {
+class TDE_EXPORT KMFCompilerInterface {
 public:
 //    KMFCompilerInterface( TQObject* parent , const char* name  ) : KParts::Plugin( parent , name ) {};
 	KMFCompilerInterface();
