@@ -14,7 +14,7 @@
 
 #include <tqptrlist.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 /**
 @author Christian Hubinger
 */
@@ -23,7 +23,7 @@ namespace KMF {
 
 
 
-class KDE_EXPORT KMFRuleEditInterface{
+class TDE_EXPORT KMFRuleEditInterface{
 public:
     KMFRuleEditInterface();
     virtual ~KMFRuleEditInterface();
