@@ -25,7 +25,7 @@
 
 #include <kmyfirewallgenericinterfacenatwidget.h>
 
-// QT Includes
+// TQt Includes
 #include <tqguardedptr.h>
 
 /**
@@ -38,7 +38,7 @@ class KMFGenericDoc;
 class NetfilterObject;
 
 class KMFGenericInterfaceNat : public KMyFirewallGenericInterfaceNATWidget {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFGenericInterfaceNat( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
