@@ -1161,7 +1161,7 @@ TQObject* KMFIPTInstallerFactory::createObject( TQObject* parent, const char* na
 // }
 
 extern "C" {
-	void* init_libkmfinstaller_linux() {
+	TDE_EXPORT void* init_libkmfinstaller_linux() {
 		return new KMFIPTInstallerFactory;
 	}
 }
