@@ -29,7 +29,7 @@ class TDE_EXPORT KMFDocumentInfo : public KMyFirewallDocumentInfo {
   
 
 public:
-	KMFDocumentInfo(TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+	KMFDocumentInfo(TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
 	~KMFDocumentInfo();
 	/*$PUBLIC_FUNCTIONS$*/
 
