@@ -13,7 +13,7 @@
 
 #include "kmfinterfacewidget.h"
 
-// QT includes
+// TQt includes
 #include <tqstringlist.h>
 
 // KDE includes
@@ -40,8 +40,8 @@
 namespace KMF {
 KMFInterfaceWidget::KMFInterfaceWidget( TQWidget* parent, const char* name, WFlags fl )
 		: KMyFirewallInterfaceWidget( parent, name, fl ) {
-		connect( m_b_add_int, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotAddInterface() ) );
-		connect( m_b_del_int, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotDelInterface() ) );
+		connect( m_b_add_int, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAddInterface() ) );
+		connect( m_b_del_int, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDelInterface() ) );
 		
 		m_cb_int_name->clear();
 		m_cb_int_name->insertItem( "eth" );
