@@ -24,7 +24,7 @@ class KMFTarget;
 
 class KMFSystemSettingsLinux : public KMyFirewallSystemSettingsLinux
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
