@@ -30,7 +30,7 @@ namespace KMF {
 class IPTRule;
 
 class KMFRuleEditorInterface : public KMyFirewallRuleEditorInterface {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleEditorInterface( TQWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
