@@ -26,7 +26,7 @@ class IPTRule;
   */
 
 class KMFRuleEditTargetLog : public KMyFirewallRuleEditorTargetLog {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleEditTargetLog( TQWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
